@@ -69,16 +69,35 @@ class browserContainer:
             # オプションクラスインスタンス
             options = chromeOptions()
             # ヘッドレスモード設定
-            options.add_argument('--headless')
+            self.setOptions(options)
             # WebDriverパスを取得
             webDriverPath = self.getWebDriverPath(self.config.chrome)
             # WebDriverを返す
-            if self.config.chrome.WebDriverLogPath == '':
-                self.wDriver = webdriver.Chrome(executable_path=webDriverPath, options=options)
-            else:
-                self.wDriver = webdriver.Chrome(executable_path=webDriverPath, log_path=self.config.chrome.WebDriverLogPath, options=options)
+            Logger.logging.info('get webdriver - start')
+            Logger.logging.info(self.config.chrome.WebDriverLogPath)
+            try:
+                if self.config.chrome.WebDriverLogPath == '':
+                    self.wDriver = webdriver.Chrome(executable_path=webDriverPath, options=options)
+                else:
+                    self.wDriver = webdriver.Chrome(executable_path=webDriverPath, log_path=self.config.chrome.WebDriverLogPath, options=options)
+                Logger.logging.info('get webdriver - end')
+            except TimeoutException as e:
+                Logger.logging.info("Selenium Exception: {0} Message: {1}".format("TimeoutException", str(e)))
+            except WebDriverException as e:
+                Logger.logging.info("Selenium Exception: {0} Message: {1}".format("WebDriverException", str(e)))
             return self.wDriver 
         
+        def setOptions(self, options:chromeOptions):
+            
+            """
+            オプション設定
+            """
+            
+            # ヘッドレスモード設定
+            options.add_argument('--headless')
+            # UA設定(速度改善の為)
+            options.add_argument('--user-agent=any')
+            
     class firefox(baseWebBrowserController):
         
         """
@@ -113,9 +132,8 @@ class browserContainer:
             
             # オプションクラスインスタンス
             options = firefoxOptions()
-            # ヘッドレスモード設定
-            options.add_argument('--headless')
-            options.add_argument('--disable-gpu')
+            # オプション設定
+            self.setOptions(options)
             # WebDriverパスを取得
             webDriverPath = self.getWebDriverPath(self.config.firefox)
             # WebDriverを返す
@@ -127,8 +145,19 @@ class browserContainer:
                 else:
                     self.wDriver = webdriver.Firefox(executable_path=webDriverPath, log_path=self.config.firefox.WebDriverLogPath, options=options)            
                 Logger.logging.info('get webdriver - end')
-            except WebDriverException as e:
-                Logger.logging.info("Selenium Exception: {0} Message: {1}".format("WebDriverException", str(e)))
             except TimeoutException as e:
                 Logger.logging.info("Selenium Exception: {0} Message: {1}".format("TimeoutException", str(e)))
+            except WebDriverException as e:
+                Logger.logging.info("Selenium Exception: {0} Message: {1}".format("WebDriverException", str(e)))
             return self.wDriver 
+        
+        def setOptions(self, options:firefoxOptions):
+            
+            """
+            オプション設定
+            """
+            
+            # ヘッドレスモード設定
+            options.add_argument('--headless')
+            # gpu無効
+            options.add_argument('--disable-gpu')
